@@ -25,8 +25,7 @@ import os
 import cookiecutter
 import cookiecutter.main
 
-from molecule import logger
-from molecule import util
+from molecule import logger, util
 
 LOG = logger.get_logger(__name__)
 
