@@ -19,8 +19,7 @@
 #  DEALINGS IN THE SOFTWARE.
 """Delegated Driver Module."""
 
-from molecule import logger
-from molecule import util
+from molecule import logger, util
 from molecule.api import Driver
 
 LOG = logger.get_logger(__name__)
